#
# spec file for package dpdk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


%define machine native
%define machine2 default
%ifarch x86_64
%define machine native
%define target x86_64-%{machine}-linuxapp-gcc
%endif
%ifarch %{ix86}
%define machine native
%define target i686-%{machine}-linuxapp-gcc
%endif
%ifarch aarch64
%define machine2 armv8a
%define target arm64-%{machine2}-linuxapp-gcc
%endif
%ifarch ppc64le
%define machine2 power8
%define target ppc_64-%{machine2}-linuxapp-gcc
%endif
%bcond_without shared
# Add option to build without examples
%bcond_without examples
# Add option to build without tools
%bcond_without tools
Name:           dpdk
Version:        16.11.8
Release:        6.8.1
Summary:        Set of libraries and drivers for fast packet processing
License:        BSD-3-Clause and GPL-2.0 and LGPL-2.1
Group:          System/Libraries
Url:            http://dpdk.org
Source:         http://fast.dpdk.org/rel/dpdk-%{version}.tar.xz
Source1:        preamble
# PATCH-FIX-OPENSUSE 0001-enic-fix-Type-punning-and-strict-aliasing-warning.patch
# This patch was originally taken from the fedora package but they have
# removed it since then because of
# http://osdir.com/ml/scm-fedora-commits/2016-03/msg00849.html
# However, the problem still exists and the fix has to find its way to the
# upstream code.
Patch1:         0001-enic-fix-Type-punning-and-strict-aliasing-warning.patch
Patch2:         0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch
Patch4:         0004-net-thunderx-sync-mailbox-definitions-with-Linux-PF-.patch
Patch5:         0005-use-cond_resched-rather-than-schedule_timeout_interr.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc6
BuildRequires:  libnuma-devel
BuildRequires:  libpcap-devel
BuildRequires:  pesign-obs-integration
BuildRequires:  zlib-devel
ExclusiveArch:  aarch64 x86_64 %ix86 ppc64le
Provides:       dpdk-any = %{version}
Conflicts:      otherproviders(dpdk-any)

%description
The Data Plane Development Kit is a set of libraries and drivers for
fast packet processing in the user space.

%package devel
Summary:        Data Plane Development Kit development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       dpdk-any-devel = %{version}
Conflicts:      otherproviders(dpdk-any-devel)

%description devel
This package contains the headers and other files needed for developing
applications with the Data Plane Development Kit.

%package doc
Summary:        Data Plane Development Kit API documentation
Group:          System/Libraries
BuildArch:      noarch
Provides:       dpdk-any-doc = %{version}
Conflicts:      otherproviders(dpdk-any-doc)

%description doc
API programming documentation for the Data Plane Development Kit.

%if %{with tools}
%package tools
Summary:        Tools for setting up Data Plane Development Kit environment
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires:       findutils
Requires:       iproute
Requires:       kmod
Requires:       pciutils
Provides:       dpdk-any-tools = %{version}
Conflicts:      otherproviders(dpdk-any-tools)

%description tools
This package contains tools for setting up Data Plane Development Kit environment
%endif

%if %{with examples}
%package examples
Summary:        Data Plane Development Kit example applications
Group:          System/Libraries
BuildRequires:  libvirt-devel
Provides:       dpdk-any-examples = %{version}
Conflicts:      otherproviders(dpdk-any-examples)

%description examples
Example applications utilizing the Data Plane Development Kit, such
as L2 and L3 forwarding.
%endif

%ifnarch %{ix86}
%package kmp
Summary:        DPDK KNI kernel module
Group:          System/Kernel
BuildRequires:  %{kernel_module_package_buildreqs}
Conflicts:      otherproviders(dpdk-any-kmp)
%suse_kernel_module_package -p %{_sourcedir}/preamble pae 64kb

%description kmp
The DPDK Kernel NIC Interface (KNI) allows userspace applications access to the Linux* control plane.
%endif

%define sdkdir  %{_datadir}/dpdk
%define docdir  %{_docdir}/dpdk
%define incdir %{_includedir}/dpdk
%define pmddir %{_libdir}/dpdk-pmds

%prep
%setup -q -n dpdk-stable-16.11.8
%patch1 -p1 -z .enic
%patch2 -p1 -z .kni1
%patch4 -p1 -z .thunderx
%patch5 -p1 -z .kni3
# This fixes CROSS compilation (broken) in the mk file for ThunderX
sed -i '/^CROSS /s/^/#/'  mk/machine/thunderx/rte.vars.mk

%build
# set up a method for modifying the resulting .config file
function setconf() {
	if grep -q ^$1= $3/.config; then
		sed -i "s:^$1=.*$:$1=$2:g" $3/.config
	else
		echo $1=$2 >> $3/.config
	fi
}

function setdefaultconf()
{
	setconf CONFIG_RTE_MACHINE '"%{machine2}"' $1
	# Disable experimental features
	setconf CONFIG_RTE_NEXT_ABI n $1

	# Enable automatic driver loading from this path
	setconf CONFIG_RTE_EAL_PMD_PATH '"%{pmddir}"' $1

	setconf CONFIG_RTE_LIBRTE_BNX2X_PMD y $1
	setconf CONFIG_RTE_LIBRTE_BNX2X_MF_SUPPORT y $1
	setconf CONFIG_RTE_LIBRTE_PMD_PCAP y $1
	setconf CONFIG_RTE_LIBRTE_VHOST_NUMA y $1

	setconf CONFIG_RTE_EAL_IGB_UIO n $1
	setconf CONFIG_RTE_KNI_KMOD n $1

	%if %{with shared}
	setconf CONFIG_RTE_BUILD_SHARED_LIB y $1
	%endif

	%ifarch aarch64 ppc64le
	setconf CONFIG_RTE_LIBRTE_DISTRIBUTOR n $1
	%endif
	%ifarch ppc64le
	setconf CONFIG_RTE_LIBRTE_PMD_RING n $1
	%endif
}
# In case dpdk-devel is installed, we should ignore its hints about the SDK directories
unset RTE_SDK RTE_INCLUDE RTE_TARGET

# For the release, '-Wno-error=array-bounds' is done to prevent a spurious error
# generated by gcc 5.X against the 2.1 branch
export EXTRA_CFLAGS="-fomit-frame-pointer -fmessage-length=0 -grecord-gcc-switches -fstack-protector -O2 -Wall -D_FORTIFY_SOURCE=2 -funwind-tables -fasynchronous-unwind-tables  -g -Wformat -fPIC -Wno-error=array-bounds"

# DPDK defaults to using builder-specific compiler flags.  However,
# the config has been changed by specifying CONFIG_RTE_MACHINE=default
# in order to build for a more generic host.  NOTE: It is possible that
# the compiler flags used still won't work for all Fedora-supported
# machines, but runtime checks in DPDK will catch those situations.

make CC=gcc-6 V=1 O=%{target} T=%{target} %{?_smp_mflags} config
setdefaultconf %{target}

%ifnarch %{ix86}
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
for flavor in %{flavors_to_build}; do
	export RTE_KERNELDIR=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor
	make CC=gcc-6 V=1 O=%{target}-$flavor T=%{target} %{?_smp_mflags} config
	setdefaultconf %{target}-$flavor
	%ifnarch %{ix86}
	setconf CONFIG_RTE_EAL_IGB_UIO y %{target}-$flavor
	setconf CONFIG_RTE_KNI_KMOD y %{target}-$flavor
	%endif
	cd  %{target}-$flavor
	make CC=gcc-6 V=1 %{?_smp_mflags}
	cd -
done
%endif

make CC=gcc-6 V=1 O=%{target} %{?_smp_mflags}
make CC=gcc-6 V=1 O=%{target} %{?_smp_mflags} doc-api-html

%if %{with examples}
make CC=gcc-6 V=1 O=%{target}/examples T=%{target} %{?_smp_mflags} examples
%endif

%install
%ifnarch %{ix86}
# export needed for kmp package
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko"

for flavor in %{flavors_to_build}; do
	cd  %{target}-$flavor
	export RTE_KERNELDIR=%{_prefix}/src/linux-obj/%{_target_cpu}/$flavor
	dir=/usr/src/linux-obj/%{_target_cpu}/$flavor
	krel=$(make -s -C "$dir" kernelrelease)
	mkdir -p %{buildroot}/lib/modules/$krel/extra/dpdk/
	#make install expects same kernel for build and target, lets copy it manually
	install -m644 ../%{target}-$flavor/kmod/*.ko %{buildroot}/lib/modules/$krel/extra/dpdk/
	cd -
done
%endif
# In case dpdk-devel is installed
unset RTE_SDK RTE_INCLUDE RTE_TARGET

%make_install O=%{target} prefix=%{_usr} libdir=%{_libdir}

%if ! %{with tools}
rm -rf %{buildroot}%{sdkdir}/tools
rm -rf %{buildroot}%{_sbindir}/dpdk_nic_bind
%endif
rm -f %{buildroot}%{sdkdir}/tools/setup.sh
#TODO pip elftools has issues to fix
rm -rf %{buildroot}%{_bindir}/dpdk-pmdinfo

%if %{with examples}
find %{target}/examples/ -name "*.map" | xargs rm -f
for f in %{target}/examples/*/%{target}/app/*; do
    bn=`basename ${f}`
    cp -p ${f} %{buildroot}%{_bindir}/dpdk_example_${bn}
done
%endif

# Create a driver directory with symlinks to all pmds
mkdir -p %{buildroot}/%{pmddir}
for f in %{buildroot}/%{_libdir}/*_pmd_*.so.*; do
    bn=$(basename ${f})
    ln -s ../${bn} %{buildroot}%{pmddir}/${bn}
done

# Setup RTE_SDK environment as expected by apps etc
mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
cat << EOF > %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk-%{_arch}.sh
if [ -z "\${RTE_SDK}" ]; then
    export RTE_SDK="%{sdkdir}"
    export RTE_TARGET="%{target}"
    export RTE_INCLUDE="%{incdir}"
fi
EOF

cat << EOF > %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk-%{_arch}.csh
if ( ! \${?RTE_SDK} ) then
    setenv RTE_SDK "%{sdkdir}"
    setenv RTE_TARGET "%{target}"
    setenv RTE_INCLUDE "%{incdir}"
endif
EOF

# Fixup target machine mismatch
sed -i -e 's:-%{machine}-:-%{machine2}-:g' %{buildroot}/%{_sysconfdir}/profile.d/dpdk-sdk*

#doc
mkdir %{buildroot}%{_docdir}/
mv   %{buildroot}%{_datadir}/doc/dpdk %{buildroot}%{_docdir}/

ln -s %{_bindir}/dpdk-procinfo %{buildroot}%{_bindir}/dpdk_proc_info
ln -s %{_sbindir}/dpdk-devbind %{buildroot}%{_sbindir}/dpdk_nic_bind

# Remove duplicates
%fdupes %{buildroot}/%{_prefix}

%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig
%post  -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
# BSD
%{_bindir}/testpmd
%{_bindir}/dpdk-procinfo
%{_bindir}/dpdk_proc_info
%{_bindir}/dpdk-pdump

%if %{with shared}
%dir %{_libdir}/dpdk-pmds

%{_libdir}/*.so.*
%{pmddir}/
%endif

%files doc
%defattr(-,root,root)
#BSD
%docdir
%doc LICENSE.GPL LICENSE.LGPL

%files devel
%defattr(-,root,root)
#BSD
%{incdir}/
%{sdkdir}
%if %{with tools}
%exclude %{sdkdir}/tools/
%endif
%if %{with examples}
%exclude %{sdkdir}/examples/
%endif
%{_sysconfdir}/profile.d/dpdk-sdk-*.*
%if ! %{with shared}
%{_libdir}/*.a
%else
%{_libdir}/*.so
%endif

%if %{with tools}
%files tools
%defattr(-,root,root)
%{sdkdir}/tools/
%{_sbindir}/dpdk-devbind
%{_sbindir}/dpdk_nic_bind
%endif

%if %{with examples}
%files examples
%defattr(-,root,root)
%{_bindir}/dpdk_example_*
%doc %{sdkdir}/examples
%endif

%changelog
* Thu Aug 30 2018 marco.varlese@suse.com
- Update to latest stable 16.11.8; some of the fixes are:
  * net/bnxt: fix HW Tx checksum offload check,
  fix incorrect IO address handling in Tx, fix Rx ring count limitation,
  check access denied for HWRM commands, fix RETA size, fix close operation
  * eal/linux: fix invalid syntax in interrupts, fix return codes on thread
  naming failure
  * kni: fix crash with null name, fix build with gcc 8.1
  * net/thunderx: fix build with gcc optimization on, avoid sq door bell
  write on zero packet
  * net/bonding: fix MAC address reset
  * vhost: fix missing increment of log cache count
- Fixed a syntax error affecting csh environment configuration(bsc#1102310)
- Rebase patch:
  [* 0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
* Mon Apr 23 2018 ndas@suse.de
- Update to 16.11.6
  restrict untrusted guest to misuse virtio to corrupt
  host application(ovs-dpdk) memory which can lead all VM to lose
  connectivity(CVE-2018-1059,bsc#1089638).
  Changes:
  * Add deprecation notice for rte_vhost_gpa_to_vva()
  * Patch vhost-net and vhost-scsi examples
  * Fixes checkpatch warnings
  * Take VIRTIO_RING_F_EVENT_IDX into account when ring size (Tiwei)
  * Fix next chuncks translation access rights in Rx paths (Tiwei)
  * vhost: fix indirect descriptors table translation size
  * vhost: check all range is mapped when translating GPAs
  * vhost: introduce safe API for GPA translation
  * vhost: ensure all range is mapped when translating QVAs
  * vhost: add support for non-contiguous indirect descs tables
  * vhost: handle virtually non-contiguous buffers in Tx
  * vhost: handle virtually non-contiguous buffers in Rx
  * vhost: handle virtually non-contiguous buffers in Rx-mrg
  * examples/vhost: move to safe GPA translation API
  * examples/vhost_scsi: move to safe GPA translation API
  * vhost/crypto: move to safe GPA translation API
  * vhost: deprecate unsafe GPA translation API
  [- 0003-kni-define-HAVE_TRANS_START_HELPER-for-SLES12SP3.patch
  * 0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
- Remove fstack-clash-protection from EXTRA_CFLAGS as gcc-6 cant
  recognize it
* Wed Feb 21 2018 ndas@suse.de
-  use cond_resched rather than schedule_timeout_interruptible(bsc#1069601)
  [+ 0005-use-cond_resched-rather-than-schedule_timeout_interr.patch]
* Wed Dec 27 2017 ndas@suse.de
- Enable broadcom chipset family Broadcom NetXtreme II BCM57810(bsc#1073363)
* Tue Apr 25 2017 ndas@suse.de
- sync mailbox definitions with Linux PF driver(bsc#1035993)
  [+0004-net-thunderx-sync-mailbox-definitions-with-Linux-PF-.patch]
* Tue Apr 18 2017 ndas@suse.de
- Enable HAVE_TRANS_START_HELPER for SLE12SP3(bsc#1031705).
  [+0003-kni-define-HAVE_TRANS_START_HELPER-for-SLES12SP3.patch]
* Tue Apr  4 2017 ndas@suse.de
- Fix dpdk KMP build fails(bsc#1031750)
- enable igb_uio kernel module(fate#322394)
- update kernel version for SLES12SP3 4.4.59 for bsc#1031705
  [*0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
* Thu Mar 30 2017 ndas@suse.de
- Enable HAVE_VF_VLAN_PROTO for SLE12SP3(bsc#1031705).
  [+0002-kni-define-HAVE_VF_VLAN_PROTO-for-SLES12SP3.patch]
* Mon Mar 20 2017 ndas@suse.de
- Disable dpdk-kmp package for ix86.
* Fri Mar  3 2017 ndas@suse.de
- Upgrade to LTS release of 16.11 which contains fixes below(fate#321541):
  * app/test: fix symmetric session free in crypto perf tests
  * app/testpmd: fix check for invalid ports
  * app/testpmd: fix static build link ordering
  * crypto/aesni_gcm: fix IV size in capabilities
  * crypto/aesni_gcm: fix J0 padding bytes
  * crypto/aesni_mb: fix incorrect crypto session
  * crypto/openssl: fix extra bytes written at end of data
  * crypto/openssl: fix indentation in guide
  * crypto/qat: fix IV size in capabilities
  * crypto/qat: fix to avoid buffer overwrite in OOP case
  * cryptodev: fix crash on null dereference
  * cryptodev: fix loop in device query
  * devargs: reset driver name pointer on parsing failure
  * drivers/crypto: fix different auth/cipher keys
  * ethdev: check maximum number of queues for statistics
  * ethdev: fix extended statistics name index
  * ethdev: fix port data mismatched in multiple process model
  * ethdev: fix port lookup if none
  * ethdev: remove invalid function from version map
  * examples/ethtool: fix driver information
  * examples/ethtool: fix querying non-PCI devices
  * examples/ip_pipeline: fix coremask limitation
  * examples/ip_pipeline: fix parsing of pass-through pipeline
  * examples/l2fwd-crypto: fix overflow
  * examples/vhost: fix calculation of mbuf count
  * examples/vhost: fix lcore initialization
  * mempool: fix API documentation
  * mempool: fix stack handler dequeue
  * net/af_packet: fix fd use after free
  * net/bnx2x: fix Rx mode configuration
  * net/cxgbe/base: initialize variable before reading EEPROM
  * net/cxgbe: fix parenthesis on bitwise operation
  * net/ena: fix setting host attributes
  * net/enic: fix hardcoding of some flow director masks
  * net/enic: fix memory leak with oversized Tx packets
  * net/enic: remove unnecessary function parameter attributes
  * net/i40e: enable auto link update for 25G
  * net/i40e: fix Rx checksum flag
  * net/i40e: fix TC bandwidth definition
  * net/i40e: fix VF reset flow
  * net/i40e: fix checksum flag in x86 vector Rx
  * net/i40e: fix crash in close
  * net/i40e: fix deletion of all macvlan filters
  * net/i40e: fix ethertype filter on X722
  * net/i40e: fix link update delay
  * net/i40e: fix logging for Tx free threshold check
  * net/i40e: fix segment number in reassemble process
  * net/i40e: fix wrong return value when handling PF message
  * net/i40e: fix xstats value mapping
  * net/i40evf: fix casting between structs
  * net/i40evf: fix reporting of imissed packets
  * net/ixgbe: fix blocked interrupts
  * net/ixgbe: fix received packets number for ARM
  * net/ixgbe: fix received packets number for ARM NEON
  * net/ixgbevf: fix max packet length
  * net/mlx5: fix RSS hash result for flows
  * net/mlx5: fix Rx packet validation and type
  * net/mlx5: fix Tx doorbell
  * net/mlx5: fix endianness in Tx completion queue
  * net/mlx5: fix inconsistent link status
  * net/mlx5: fix leak when starvation occurs
  * net/mlx5: fix link status query
  * net/mlx5: fix memory leak when parsing device params
  * net/mlx5: fix missing inline attributes
  * net/mlx5: fix updating total length of multi-packet send
  * net/mlx: fix IPv4 and IPv6 packet type
  * net/nfp: fix VLAN offload flags check
  * net/nfp: fix typo in Tx offload capabilities
  * net/pcap: fix timestamps in output pcap file
  * net/qede/base: fix FreeBSD build
  * net/qede: add vendor/device id info
  * net/qede: fix PF fastpath status block index
  * net/qede: fix filtering code
  * net/qede: fix function declaration
  * net/qede: fix per queue statisitics
  * net/qede: fix resource leak
  * net/vhost: fix socket file deleted on stop
  * net/vhost: fix unix socket not removed as closing
  * net/virtio-user: fix not properly reset device
  * net/virtio-user: fix wrongly get/set features
  * net/virtio: fix build without virtio-user
  * net/virtio: fix crash when number of virtio devices > 1
  * net/virtio: fix multiple process support
  * net/virtio: fix performance regression due to TSO
  * net/virtio: fix rewriting LSC flag
  * net/virtio: fix wrong Rx/Tx method for secondary process
  * net/virtio: optimize header reset on any layout
  * net/virtio: store IO port info locally
  * net/virtio: store PCI operators pointer locally
  * net/vmxnet3: fix Rx deadlock
  * pci: fix check of mknod
  * pmdinfogen: fix endianness with cross-compilation
  * pmdinfogen: fix null dereference
  * sched: fix crash when freeing port
  * usertools: fix active interface detection when binding
  * vdev: fix detaching with alias
  * vfio: fix file descriptor leak in multi-process
  * vhost: allow many vhost-user ports
  * vhost: do not GSO when no header is present
  * vhost: fix dead loop in enqueue path
  * vhost: fix guest/host physical address mapping
  * vhost: fix long stall of negotiation
  * vhost: fix memory leak
* Fri Feb 24 2017 ndas@suse.de
- Fix broken dpdk-pmd/* soft links(bsc#1026804).
* Thu Feb 16 2017 ndas@suse.de
- Do not disable cryptodev as EXPREMENTAL tag has been removed.
- Remove CONFIG_RTE_LIBRTE_MBUF_OFFLOAD as cryptodev is not depending
  on it anymore and its removed from the upstream.
* Fri Feb 10 2017 ndas@suse.de
- Enable rte_kni kernel module for dpdk(fate#322394).
  [+preamble]
- Build dpdk-thunderx only for aarch64
* Thu Feb  2 2017 ndas@suse.de
- Update to version 16.11(fate#321541). Some of the new features are listed below:
  * Added software parser for packet type.
  * Improved offloads support in mbuf.
  * Added vhost-user dequeue zero copy support.
  * Added vhost-user indirect descriptors support.
  * Added vhost PMD xstats.
  * Added virtio NEON support for ARM.
  * Updated the ixgbe base driver.
  * Added APIs for VF management to the ixgbe PMD.
  * Updated the enic driver.
  * Added openssl PMD.
  * Added support for new gcc -march option.
  Detailed changes can be obtained from http://dpdk.org/doc/guides/rel_notes/release_16_11.html
- Resolved fixes in the updated versions are :
  * enic: Fixed several flow director issues.
  * enic: Fixed inadvertent setting of L4 checksum ptype on ICMP packets.
  * enic: Fixed high driver overhead when servicing Rx queues beyond the first.
* Fri Jan 20 2017 ndas@suse.de
- Added gcc-6 as default compiler for CRC/mtune & other optimizations.
- Fix possible parallel installation of dpdk subpackages.
* Wed Jan  4 2017 ndas@suse.de
- Add pre_checkin.sh to generate the dpdk-thunderx.spec file
* Mon Dec 12 2016 marco.varlese@suse.com
- Fixed paths using %%{name} to have the dpdk.spec aligned with dpdk-thunderx.spec
* Mon Dec 12 2016 marco.varlese@suse.com
- Added back in all the architectures to keep .spec files aligned
  * Driving thunderx platform architectural dependency via the ExclusiveArch tag
* Mon Dec 12 2016 mvarlese@suse.com
- Added support to build code for Thunderx platform(fate#321960).
- Introduced new dpdk-thunderx.spec file:
  * Removed architectures not supporting Thunderx platform (e.g. x86)
  * Added dependency on gcc v5.0 for armv8a-crc
* Wed Nov 30 2016 mchandras@suse.de
- Update to version 16.07.2. Some of the fixes are listed below:
  * ethdev: prevent duplicate event callback
  * hash: fix bucket size usage
  * hash: fix unlimited cuckoo path
  * lpm: fix freeing memory
  * lpm: fix freeing unused sub-table on rule delete
  * mempool: fix leak if populate fails
  * mempool: fix search of maximum contiguous pages
  * pci: fix probing error if no driver found
  * net/bnx2x: fix maximum PF queues
  * net/bnxt: fix bit shift size
  * net/bnxt: fix crash when closing
  * net/enic: fix Rx queue index when not using Rx scatter
  * net/enic: fix crash on MTU update or Rx queue reconfigure
  * net/enic: fix crash with removed flow director filters
  * net/enic: fix max packet length check
  * net/enic: fix multi-queue Rx performance
  * net/enic: revert truncated packets counter fix
  * net/fm10k: fix VF Tx queue initialization
  * net/i40e: fix Rx hang when disable LLDP
  * net/ixgbe: fix VF registers
  * net/thunderx: fix Tx checksum handling
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides-16.07/rel_notes/release_16_07.html#id2]
* Thu Nov 24 2016 mchandras@suse.de
- Update to version 16.07.1. Some of the fixes are listed below:
  * contigmem: zero all pages during mmap
  * crypto/null: fix key size increment value
  * hash: fix false zero signature key hit lookup
  * mem: fix crash on hugepage mapping error
  * mbuf: fix error handling on pool creation
  * net/e1000: fix returned number of available Rx descriptors
  * net/enic: fix freeing memory for descriptor ring
  * net/i40e: fix dropping packets with ethertype 0x88A8
  * net/i40e: fix mbuf leak during Rx queue release
  * net/i40e: fix null pointer dereferences when using VMDq+RSS
  * net/ixgbe/base: fix possible corruption of shadow RAM
  * net/ixgbe: fix VF reset to apply to correct VF
  * net/virtio_user: fix error management during init
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides-16.07/rel_notes/release_16_07.html#fixes-in-16-07-01-stable-release]
* Thu Oct  6 2016 mchandras@suse.de
- Drop code for generating our own linker script.
  * Commit 948fd64befc3 (" mk: replace the combined library with a
    linker script") added upstream support for building and installing
    a linker script so we drop our code from the spec file which
    generated a much larger and possibly broken linker script resulting
    to linking issues (boo#1002534)
* Wed Aug 10 2016 ndas@suse.de
- Update to version 16.07. Some of the new features are listed below:
  * Removed the mempool cache memory if caching is not being used.
  * Added mempool external cache for non-EAL thread.
  * Changed the memory allocation scheme in the mempool library.
  * Added a new driver for Broadcom NetXtreme-C devices.
  * Added a new driver for ThunderX nicvf devices.
  * Added mailbox interrupt support for ixgbe and igb VFs.
  * Updated the ixgbe base driver.
  * Updated the i40e base driver.
  * Updated the enic driver.
  * Updated the mlx5 driver.
  * Added support for virtio on IBM POWER8.
  * Added support for Virtio in containers.
  * Added vhost-user client mode.
  * Added NSH packet recognition in i40e.
  * Added AES-CTR support to AESNI MB PMD.
  * Added AES counter mode support for Intel QuickAssist devices.
  * Added KASUMI SW PMD.
  * Added multi-writer support for RTE Hash with Intel TSX.
  * Improved IP Pipeline Application.
  * Added keepalive enhancements.
  * Added packet capture framework.
  * Added floating VEB support for i40e PF driver.
  * Added support for live migration of a VM with SRIOV VF.
  * [The list of changes is rather long so please consult the following
    resources for the complete list of new features, bugfixes and other
    changes in this release:
  - http://dpdk.org/doc/guides/rel_notes/release_16_07.html
  - http://dpdk.org/browse/dpdk/tree/doc/guides/rel_notes/release_16_07.rst
  - Or the doc/guides/rel_notes/release_16_07.rst file in the released
    tarball.]
- Removed patches that are already avilable in dpdk-16.07
  [ -0002-examples-ip_pipeline-fix-implicit-declaration-of-fun.patch
  - 0003-mk-fix-external-shared-library-dependencies-of-libraries.patch
  - 0004-54f9e32-vhost-handle-dirty-pages-logging-request.patch
  - 0005-d293dac-vhost-claim-support-of-guest-announce.patch
  - 0006-d639996-vhost-enable-log_shmfd-protocol-feature.patch
  - 0007-ixgbe-fix-VLAN-filter-missing-brackets.patch
  - 0008-app-testpmd-handle-SIGINT-and-SIGTERM.patch
  - 0009-bonding-copy-entire-config-structure-in-mode-4.patch
  - 0010-bonding-fix-active-slaves-with-no-primary.patch
  - 0011-bonding-do-not-ignore-multicast-in-mode-4.patch
  - 0012-bonding-do-not-activate-slave-twice.patch
  - 0013-bonding-fix-crash-when-no-slave-device.patch
  - 0014-bonding-fix-detach-of-bonded-device.patch
  - 0015-bonding-fix-detach-of-slave-devices.patch
  - 0016-eal-linux-support-built-in-kernel-modules.patch
  - 0017-examples-l3fwd-handle-SIGINT-and-SIGTERM.patch
  - 0018-fm10k-fix-VLAN-flag-in-scattered-Rx.patch
  - 0019-i40e-base-fix-driver-load-failure.patch
  - 0020-i40e-base-fix-missing-check-for-stopped-admin-queue.patch
  - 0021-i40e-fix-inverted-check-for-no-refcount.patch
  - 0022-i40e-fix-overflow.patch
  - 0023-i40e-fix-VLAN-filtering.patch
  - 0024-mempool-fix-leak-when-creation-fails.patch
  - 0025-pcap-fix-captured-frame-length.patch
  - 0026-port-fix-crash-for-ethdev-writer-nodrop.patch
  - 0027-port-fix-crash-for-ring-writer-nodrop.patch
  - 0028-tools-fix-unbinding-failure-handling.patch
  - 0029-tools-support-Python-3-in-bind-script.patch
  - 0030-tools-support-binding-to-built-in-kernel-modules.patch
  - 0031-vhost-fix-leak-of-fds-and-mmaps.patch
  - 0032-virtio-fix-crash-in-statistics-functions.patch
  - 0033-virtio-fix-descriptors-pointing-to-the-same-buffer.patch
  - 0034-virtio-fix-restart.patch
  - 0035-PAGE_SIZE-constant-is-not-defined-on-ARM-since-multi.patch
  - 0036-examples-fix-build-dependencies.patch
  - 0037-examples-ethtool-fix-build.patch
  - 0099-mk-fix-gcc-5-version-on-suse.patch
  - 0100-kni-fix-build-with-gcc-6.patch
  - 0101-ixgbe-fix-uninitialized-warning.patch
  - 0102-ixgbe-fix-constant-sign-in-left-shift-operator.patch
  - 0103-e1000-base-Add-missing-braces-to-the-if-statements.patch
  - 0104-igb-fix-constant-sign-in-left-shift-operator.patch
  - 0105-e1000-fix-missing-link-interrupt-check-brackets.patch
  - 0106-app-test-fix-missing-brackets.patch
  - 0107-examples-ip_pipeline-use-unsigned-constants-for-left.patch
  ]
- Created soft link for dpdk_proc_info and dpdk_nic_bind(from dpdk-procinfo, dpdk-devbind) to keep compatibility.
- Added a new binary dpdk-pdump dpdk-procinfo
* Thu Jul 28 2016 ndas@suse.de
- Add _constraints file to force build dpdk with sse3 enabled x86 machine(bsc#993462).
- Enable compilation for  ppc64le with the help of Rüdiger(ro@suse.de).
- Enable example package for aarch64 using Rüdiger(ro@suse.de) changes.
- Do not enable PMD_RING on ppc64le (missing rte_eth_from_rings).
- Disable examples that need LPM which is disabled on non-x86.
  [+0036-examples-fix-build-dependencies.patch,
  +0037-examples-ethtool-fix-build.patch,
  +_constraints]
* Mon Jul 11 2016 ndas@suse.de
- Added support for aarch64 compilation.
  [+0035-PAGE_SIZE-constant-is-not-defined-on-ARM-since-multi.patch]
- Disabled aarch64 dpdk-examples package for the time being as it
  contains lots of Intel specific code.
- Added proper "Group" field for the subpackages .
* Thu Jun 23 2016 mchandras@suse.de
- Add upstream patches to fix building with gcc >= 6
  * 0100-kni-fix-build-with-gcc-6.patch
  * 0101-ixgbe-fix-uninitialized-warning.patch
  * 0102-ixgbe-fix-constant-sign-in-left-shift-operator.patch
  * 0103-e1000-base-Add-missing-braces-to-the-if-statements.patch
  * 0104-igb-fix-constant-sign-in-left-shift-operator.patch
  * 0105-e1000-fix-missing-link-interrupt-check-brackets.patch
  * 0106-app-test-fix-missing-brackets.patch
  * 0107-examples-ip_pipeline-use-unsigned-constants-for-left.patch
* Tue Jun 14 2016 ndas@suse.de
- Removed unwanted files(bsc#984437).
* Thu Jun  9 2016 ndas@suse.de
- Added missing GPL-2.0 and LGPL-2.1 licenses.
* Wed Jun  1 2016 mchandras@suse.de
- Update tarball URL.
* Fri May 27 2016 ndas@suse.de
- Applied all the fixes recommended by upstream for
  v2.2 stable release(bsc#981996).
  [+0008-app-testpmd-handle-SIGINT-and-SIGTERM.patch,
  +0009-bonding-copy-entire-config-structure-in-mode-4.patch,
  +0010-bonding-fix-active-slaves-with-no-primary.patch,
  +0011-bonding-do-not-ignore-multicast-in-mode-4.patch,
  +0012-bonding-do-not-activate-slave-twice.patch,
  +0013-bonding-fix-crash-when-no-slave-device.patch,
  +0014-bonding-fix-detach-of-bonded-device.patch,
  +0015-bonding-fix-detach-of-slave-devices.patch,
  +0016-eal-linux-support-built-in-kernel-modules.patch,
  +0017-examples-l3fwd-handle-SIGINT-and-SIGTERM.patch,
  +0018-fm10k-fix-VLAN-flag-in-scattered-Rx.patch,
  +0019-i40e-base-fix-driver-load-failure.patch,
  +0020-i40e-base-fix-missing-check-for-stopped-admin-queue.patch,
  +0021-i40e-fix-inverted-check-for-no-refcount.patch,
  +0022-i40e-fix-overflow.patch,
  +0023-i40e-fix-VLAN-filtering.patch,
  +0024-mempool-fix-leak-when-creation-fails.patch,
  +0025-pcap-fix-captured-frame-length.patch,
  +0026-port-fix-crash-for-ethdev-writer-nodrop.patch,
  +0027-port-fix-crash-for-ring-writer-nodrop.patch,
  +0028-tools-fix-unbinding-failure-handling.patch,
  +0029-tools-support-Python-3-in-bind-script.patch,
  +0030-tools-support-binding-to-built-in-kernel-modules.patch,
  +0031-vhost-fix-leak-of-fds-and-mmaps.patch,
  +0032-virtio-fix-crash-in-statistics-functions.patch,
  +0033-virtio-fix-descriptors-pointing-to-the-same-buffer.patch,
  +0034-virtio-fix-restart.patch]
* Wed May 11 2016 mchandras@suse.de
- Use fdupes to manage duplicate files
* Thu Apr 28 2016 ndas@suse.de
- Create DPDK packages for 32 bit x86(bsc#977639).
* Wed Apr 27 2016 mchandras@suse.de
- Add upstream patch for the ixgbe driver
  * 0007-ixgbe-fix-VLAN-filter-missing-brackets.patch: Fix VLAN
    filtering logic by adding the missing brackets in the 'if' statement.
* Tue Apr 19 2016 ndas@suse.de
- DPDK is most common vhost-user backend, Adding upstream patches to
  help qemu vm live migration with vhost-user (fate#320713).
  [+ 0004-54f9e32-vhost-handle-dirty-pages-logging-request.patch
  + 0005-d293dac-vhost-claim-support-of-guest-announce.patch
  + 0006-d639996-vhost-enable-log_shmfd-protocol-feature.patch]
* Wed Apr 13 2016 mchandras@suse.de
- Move the combined library back to the devel package (bsc#975123)
  Ever since we dropped the CONFIG_RTE_BUILD_COMBINE_LIBS=y option, the
  libdpdk.so is no longer a shared object but rather a linker script
  generated by the spec file. This means that it is only used during
  linking and the linker will add the individual DPDK libraries to the
  DT_NEEDED tag on the dependent binaries.
* Tue Apr 12 2016 mchandras@suse.de
- Fix shared linking against libdpdk.so (bsc#975123)
  * Restore the 0003-mk-fix-external-shared-library-dependencies-of-libraries.patch
    patch which sets the correct dependencies for the shared libraries.
  * Drop CONFIG_RTE_BUILD_COMBINE_LIBS since a custom linker script
    is used to create and install a more lightweight version of libdpdk.so.
  * Include the combined libdpdk.so library to the regular package since it
    is also necessary during runtime.
* Mon Apr 11 2016 ndas@suse.de
- Removed unwnated patch and reformated patch file names(bsc#974903).
  [- dpdk-2.2-dtneeded.patch,
  - dpdk-2.2-examples.patch,
  - enic-pun-fix.patch,
  - dpdk-2.2-warningflags.patch,
  + 0001-enic-fix-Type-punning-and-strict-aliasing-warning.patch
  + 0002-examples-ip_pipeline-fix-implicit-declaration-of-fun.patch]
- Added CONFIG_RTE_BUILD_COMBINE_LIBS flags to club all all *.so into
  one library
* Mon Mar 21 2016 nirmoy.das@suse.com
- Intial version 2.2.0(fate#319169)
